import { OnDestroy, Injector } from "@angular/core";
import { Subscription, Observable } from "rxjs";
import { ActivatedRoute, Router, Params } from "@angular/router";
import { BBAlertService, BBConfirmService } from "angular-bootstrap-ui";
import { ToastrService } from 'ngx-toastr';
import { Logger } from "./Logger";
import { SessionStorageService } from "./session-storage.service";
/**
 * Base class for componets to extends that handle many common staff
 * * route, parameters and resolved
 * * router
 * * modal confirmations
 * * modal alerts
 * * unsubscription to subscriptions when component is destroyed
 * * log
 * * session (localStorage)
 */
export declare class Base implements OnDestroy {
    injector: Injector;
    route: ActivatedRoute;
    subscriptions: Subscription[];
    timeouts: number[];
    toastrService: ToastrService;
    session: SessionStorageService;
    router: Router;
    currentLog: Logger;
    confirmService: BBConfirmService;
    alertService: BBAlertService;
    parameterListeners: {
        [paramName: string]: (value: any) => void;
    };
    /**
     * Fetch some things that most componets uses and init route listeners
     */
    constructor(injector: Injector, route: ActivatedRoute);
    /**
     * parameter changed listener
     */
    protected parameterChanged(p: Params): void;
    /**
     * Notify given callback when a change in parameters is detected
     * that not means that paramName is changed
     */
    onParameterChange(paramName: string, cb: (value: any) => void): void;
    /**
     * Keep your member in sync with a parameter with the same name
     */
    bindParameter(paramName: any): void;
    /**
     * Add the subscription to a list that will unsubscribe when componet
     * is destroyed
     */
    handleSubscription(s: Subscription): void;
    /**
     * Create a timeout that is cleared if the componet is destroyed
     */
    timeout(fn: Function, miliseconds: number): number;
    /**
     * unsubscibe and clear timeouts
     *
     * NOTE: If You need to override ngOnDestroy remember to always call super()
     */
    ngOnDestroy(): void;
    /**
     * Create an error growl, require ngx-toaster to be configured
     */
    errGrowl(str: string, timeout?: number): void;
    /**
     * Create a warning growl, require ngx-toaster to be configured
     */
    warnGrowl(str: string, timeout?: number): void;
    /**
     * Create an info growl, require ngx-toaster to be configured
     */
    growl(str: string, timeout?: number): void;
    /**
     * Reverse ActivatedRoute and return the first non-undefined key in params
     */
    getParameter(key: string): string | null;
    /**
     * Reverse ActivatedRoute and return the first non-undefined key in params
     * casted to number (Integer)
     */
    getNumberParameter(key: string): number | null;
    /**
     * Reverse ActivatedRoute and return the first non-undefined key in data
     */
    getResolve<T>(key: string): T;
    /**
     * Create a confirmation modal
     * bb-confirm-service need to be configured
     */
    confirm(header: string, content: string): Observable<boolean>;
    /**
     * Create a alert modal
     * bb-alert-service need to be configured
     */
    alert(header: string, content: string, isHTML: boolean): Observable<boolean>;
}
